@@ -2,7 +2,7 @@ package commands
 
 import (
 	"context"
-	"github.com/kluctl/kluctl/v2/pkg/status"
+	"github.com/kluctl/kluctl/lib/status"
 	"github.com/kluctl/kluctl/v2/pkg/version"
 )
 
