@@ -3,8 +3,8 @@ package commands
 import (
 	"context"
 	"fmt"
+	"github.com/kluctl/kluctl/lib/status"
 	"github.com/kluctl/kluctl/v2/pkg/results"
-	"github.com/kluctl/kluctl/v2/pkg/status"
 	"github.com/kluctl/kluctl/v2/pkg/webui"
 	"time"
 )
@@ -26,7 +26,7 @@ func (cmd *webuiBuildCmd) Run(ctx context.Context) error {
 		return fmt.Errorf("this build of Kluctl does not have the webui embedded")
 	}
 
-	stores, _, err := createResultStores(ctx, cmd.Context, cmd.AllContexts, false)
+	stores, _, err := createResultStores(ctx, "", cmd.Context, cmd.AllContexts, false)
 	if err != nil {
 		return err
 	}
