@@ -3,8 +3,9 @@ package commands
 import (
 	"context"
 	"fmt"
+	"github.com/kluctl/kluctl/lib/status"
+	"github.com/kluctl/kluctl/v2/cmd/kluctl/args"
 	"github.com/kluctl/kluctl/v2/pkg/results"
-	"github.com/kluctl/kluctl/v2/pkg/status"
 	"github.com/kluctl/kluctl/v2/pkg/webui"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/clientcmd"
@@ -13,10 +14,13 @@ import (
 )
 
 type webuiRunCmd struct {
-	Host        string   `group:"misc" help:"Host to bind to. Pass an empty string to bind to all addresses. Defaults to 'localhost' when run locally and to all hosts when run in-cluster."`
-	Port        int      `group:"misc" help:"Port to bind to." default:"8080"`
-	Context     []string `group:"misc" help:"List of kubernetes contexts to use."`
-	AllContexts bool     `group:"misc" help:"Use all Kubernetes contexts found in the kubeconfig."`
+	Host       string `group:"misc" help:"Host to bind to. Pass an empty string to bind to all addresses. Defaults to 'localhost' when run locally and to all hosts when run in-cluster."`
+	Port       int    `group:"misc" help:"Port to bind to." default:"8080"`
+	PathPrefix string `group:"misc" help:"Specify the prefix of the path to serve the webui on. This is required when using a reverse proxy, ingress or gateway that serves the webui on another path than /." default:"/"`
+
+	Kubeconfig  args.ExistingFileType `group:"misc" help:"Overrides the kubeconfig to use."`
+	Context     []string              `group:"misc" help:"List of kubernetes contexts to use."`
+	AllContexts bool                  `group:"misc" help:"Use all Kubernetes contexts found in the kubeconfig."`
 
 	InCluster           bool   `group:"misc" help:"This enables in-cluster functionality. This also enforces authentication."`
 	InClusterContext    string `group:"misc" help:"The context to use fo in-cluster functionality."`
@@ -143,7 +147,7 @@ func (cmd *webuiRunCmd) Run(ctx context.Context) error {
 		}
 	}
 
-	stores, configs, err := createResultStores(ctx, cmd.Context, cmd.AllContexts, cmd.InCluster)
+	stores, configs, err := createResultStores(ctx, cmd.Kubeconfig.String(), cmd.Context, cmd.AllContexts, cmd.InCluster)
 	if err != nil {
 		return err
 	}
@@ -151,7 +155,7 @@ func (cmd *webuiRunCmd) Run(ctx context.Context) error {
 	collector := results.NewResultsCollector(ctx, stores)
 	collector.Start()
 
-	server, err := webui.NewCommandResultsServer(ctx, collector, configs, cmd.ControllerNamespace, inClusterConfig, inClusterClient, authConfig, cmd.OnlyApi)
+	server, err := webui.NewCommandResultsServer(ctx, collector, configs, cmd.ControllerNamespace, inClusterConfig, inClusterClient, authConfig, cmd.PathPrefix, cmd.OnlyApi)
 	if err != nil {
 		return err
 	}
