@@ -22,9 +22,7 @@ func TestOciIncludeMultipleRepos(t *testing.T) {
 	ip1 := prepareIncludeProject(t, "include1", "", nil)
 	ip2 := prepareIncludeProject(t, "include2", "subDir", nil)
 
-	repo := &test_utils.TestHelmRepo{
-		Oci: true,
-	}
+	repo := test_utils.NewHelmTestRepo(test_utils.TestHelmRepo_Oci, "", nil)
 	repo.Start(t)
 
 	repo1 := repo.URL.String() + "/org1/repo1"
@@ -64,13 +62,9 @@ func TestOciIncludeWithCreds(t *testing.T) {
 	ip3 := prepareIncludeProject(t, "include3", "", nil)
 
 	createRepo := func(user, pass string) *test_utils.TestHelmRepo {
-		repo := &test_utils.TestHelmRepo{
-			TestHttpServer: test_utils.TestHttpServer{
-				Username: user,
-				Password: pass,
-			},
-			Oci: true,
-		}
+		repo := test_utils.NewHelmTestRepo(test_utils.TestHelmRepo_Oci, "", nil)
+		repo.HttpServer.Username = user
+		repo.HttpServer.Password = pass
 		repo.Start(t)
 		return repo
 	}
@@ -170,7 +164,7 @@ func TestOciIncludeTagsAndDigests(t *testing.T) {
 	ip1 := prepareIncludeProject(t, "include1", "", nil)
 
 	repo := test_utils.TestHelmRepo{
-		Oci: true,
+		Type: test_utils.TestHelmRepo_Oci,
 	}
 	repo.Start(t)
 
