@@ -17,6 +17,18 @@ import (
 	"time"
 )
 
+func createTestCluster(t *testing.T, context string) *test_utils.EnvTestCluster {
+	k := test_utils.CreateEnvTestCluster(context)
+	err := k.Start()
+	if err != nil {
+		t.Fatal(err)
+	}
+	t.Cleanup(func() {
+		k.Stop()
+	})
+	return k
+}
+
 func createNamespace(t *testing.T, k *test_utils.EnvTestCluster, namespace string) {
 	r := k.DynamicClient.Resource(v1.SchemeGroupVersion.WithResource("namespaces"))
 	if _, err := r.Get(context.Background(), namespace, metav1.GetOptions{}); err == nil {
@@ -44,23 +56,27 @@ func getHeadRevision(t *testing.T, p *test_project.TestProject) string {
 func assertObjectExists(t *testing.T, k *test_utils.EnvTestCluster, gvr schema.GroupVersionResource, namespace string, name string) *uo.UnstructuredObject {
 	x, err := k.Get(gvr, namespace, name)
 	if err != nil {
-		t.Fatalf("unexpected error '%v' while getting ConfigMap %s/%s", err, namespace, name)
+		t.Fatalf("unexpected error '%v' while getting %s %s/%s", err, gvr.GroupResource().String(), namespace, name)
 	}
 	return x
 }
 
+func assertObjectNotExists(t *testing.T, k *test_utils.EnvTestCluster, gvr schema.GroupVersionResource, namespace string, name string) {
+	_, err := k.Get(gvr, namespace, name)
+	if err == nil {
+		t.Fatalf("expected %s/%s to not exist", namespace, name)
+	}
+	if !errors.IsNotFound(err) {
+		t.Fatalf("unexpected error '%v' for %s/%s, expected a NotFound error", err, namespace, name)
+	}
+}
+
 func assertConfigMapExists(t *testing.T, k *test_utils.EnvTestCluster, namespace string, name string) *uo.UnstructuredObject {
 	return assertObjectExists(t, k, v1.SchemeGroupVersion.WithResource("configmaps"), namespace, name)
 }
 
 func assertConfigMapNotExists(t *testing.T, k *test_utils.EnvTestCluster, namespace string, name string) {
-	_, err := k.Get(v1.SchemeGroupVersion.WithResource("configmaps"), namespace, name)
-	if err == nil {
-		t.Fatalf("expected %s/%s to not exist", namespace, name)
-	}
-	if !errors.IsNotFound(err) {
-		t.Fatalf("unexpected error '%v' for %s/%s, expected a NotFound error", err, namespace, name)
-	}
+	assertObjectNotExists(t, k, v1.SchemeGroupVersion.WithResource("configmaps"), namespace, name)
 }
 
 func assertSecretExists(t *testing.T, k *test_utils.EnvTestCluster, namespace string, name string) *uo.UnstructuredObject {
