@@ -9,14 +9,15 @@ import (
 const (
 	KluctlDeploymentControllerSubsystem = "kluctldeployments"
 
-	DeploymentIntervalKey = "deployment_interval_seconds"
-	DryRunEnabledKey      = "dry_run_enabled"
-	LastObjectStatusKey   = "last_object_status"
-	PruneEnabledKey       = "prune_enabled"
-	DeleteEnabledKey      = "delete_enabled"
-	SourceSpecKey         = "source_spec"
-	GitSourceSpecKey      = "git_source_spec"
-	OciSourceSpecKey      = "oci_source_spec"
+	DeploymentIntervalKey  = "deployment_interval_seconds"
+	DryRunEnabledKey       = "dry_run_enabled"
+	LastObjectStatusKey    = "last_object_status"
+	LastDeployStartTimeKey = "last_deploy_start_timestamp_seconds"
+	PruneEnabledKey        = "prune_enabled"
+	DeleteEnabledKey       = "delete_enabled"
+	SourceSpecKey          = "source_spec"
+	GitSourceSpecKey       = "git_source_spec"
+	OciSourceSpecKey       = "oci_source_spec"
 )
 
 var (
@@ -38,6 +39,12 @@ var (
 		Help:      "Last object status of a single deployment.",
 	}, []string{"namespace", "name"})
 
+	lastDeployStartTime = prometheus.NewGaugeVec(prometheus.GaugeOpts{
+		Subsystem: KluctlDeploymentControllerSubsystem,
+		Name:      LastDeployStartTimeKey,
+		Help:      "Last start time of a single deployment.",
+	}, []string{"namespace", "name"})
+
 	pruneEnabled = prometheus.NewGaugeVec(prometheus.GaugeOpts{
 		Subsystem: KluctlDeploymentControllerSubsystem,
 		Name:      PruneEnabledKey,
@@ -73,6 +80,7 @@ func init() {
 	metrics.Registry.MustRegister(deploymentInterval)
 	metrics.Registry.MustRegister(dryRunEnabled)
 	metrics.Registry.MustRegister(lastObjectStatus)
+	metrics.Registry.MustRegister(lastDeployStartTime)
 	metrics.Registry.MustRegister(pruneEnabled)
 	metrics.Registry.MustRegister(deleteEnabled)
 	metrics.Registry.MustRegister(sourceSpec)
@@ -90,6 +98,10 @@ func NewKluctlLastObjectStatus(namespace string, name string) prometheus.Gauge {
 	return lastObjectStatus.WithLabelValues(namespace, name)
 }
 
+func NewKluctlLastDeployStartTime(namespace string, name string) prometheus.Gauge {
+	return lastDeployStartTime.WithLabelValues(namespace, name)
+}
+
 func NewKluctlPruneEnabled(namespace string, name string) prometheus.Gauge {
 	return pruneEnabled.WithLabelValues(namespace, name)
 }
