@@ -5,14 +5,14 @@ import (
 	"crypto/sha256"
 	"encoding/hex"
 	"fmt"
+	"github.com/kluctl/kluctl/lib/status"
+	"github.com/kluctl/kluctl/lib/yaml"
 	"github.com/kluctl/kluctl/v2/pkg/helm"
 	"github.com/kluctl/kluctl/v2/pkg/k8s"
-	"github.com/kluctl/kluctl/v2/pkg/status"
 	"github.com/kluctl/kluctl/v2/pkg/types"
 	k8s2 "github.com/kluctl/kluctl/v2/pkg/types/k8s"
 	"github.com/kluctl/kluctl/v2/pkg/utils"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
-	"github.com/kluctl/kluctl/v2/pkg/yaml"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"path/filepath"
 	"sync"
@@ -24,19 +24,17 @@ type DeploymentCollection struct {
 	Project   *DeploymentProject
 	Images    *Images
 	Inclusion *utils.Inclusion
-	forSeal   bool
 
 	Deployments []*DeploymentItem
 	mutex       sync.Mutex
 }
 
-func NewDeploymentCollection(ctx SharedContext, project *DeploymentProject, images *Images, inclusion *utils.Inclusion, forSeal bool) (*DeploymentCollection, error) {
+func NewDeploymentCollection(ctx SharedContext, project *DeploymentProject, images *Images, inclusion *utils.Inclusion) (*DeploymentCollection, error) {
 	dc := &DeploymentCollection{
 		ctx:       ctx,
 		Project:   project,
 		Images:    images,
 		Inclusion: inclusion,
-		forSeal:   forSeal,
 	}
 
 	indexes := make(map[string]int)
@@ -93,7 +91,9 @@ func (c *DeploymentCollection) collectAllDeployments(project *DeploymentProject,
 		return nil, err
 	}
 
-	for i, diConfig := range project.Config.Deployments {
+	for i, _ := range project.Config.Deployments {
+		diConfig := &project.Config.Deployments[i]
+
 		whenTrue, err := project.VarsCtx.CheckConditional(diConfig.When)
 		if err != nil {
 			return nil, err
@@ -137,7 +137,7 @@ func (c *DeploymentCollection) RenderDeployments() error {
 	for _, d := range c.Deployments {
 		d := d
 		g.RunE(func() error {
-			return d.render(c.forSeal)
+			return d.render()
 		})
 	}
 	g.Wait()
@@ -166,20 +166,6 @@ func (c *DeploymentCollection) renderHelmCharts() error {
 	return g.ErrorOrNil()
 }
 
-func (c *DeploymentCollection) resolveSealedSecrets() error {
-	if c.forSeal {
-		return nil
-	}
-
-	for _, d := range c.Deployments {
-		err := d.resolveSealedSecrets()
-		if err != nil {
-			return err
-		}
-	}
-	return nil
-}
-
 func (c *DeploymentCollection) buildKustomizeObjects() error {
 	g := utils.NewGoHelper(c.ctx.Ctx, 0)
 
@@ -351,10 +337,6 @@ func (c *DeploymentCollection) Prepare() error {
 	if err != nil {
 		return err
 	}
-	err = c.resolveSealedSecrets()
-	if err != nil {
-		return err
-	}
 	err = c.buildKustomizeObjects()
 	if err != nil {
 		return err
