@@ -3,12 +3,23 @@ package helm
 import (
 	"context"
 	"fmt"
+	"github.com/kluctl/kluctl/lib/git/types"
+	types2 "github.com/kluctl/kluctl/v2/pkg/types"
+	"net/url"
+	"os"
+	"path"
+	"path/filepath"
+	"regexp"
+	"sort"
+	"strings"
+
 	"github.com/Masterminds/semver/v3"
 	"github.com/google/go-containerregistry/pkg/crane"
 	"github.com/kluctl/kluctl/lib/status"
 	"github.com/kluctl/kluctl/lib/yaml"
-	"github.com/kluctl/kluctl/v2/pkg/helm/auth"
-	"github.com/kluctl/kluctl/v2/pkg/oci/auth_provider"
+	helmauth "github.com/kluctl/kluctl/v2/pkg/helm/auth"
+	ociauth "github.com/kluctl/kluctl/v2/pkg/oci/auth_provider"
+	"github.com/kluctl/kluctl/v2/pkg/repocache"
 	"github.com/kluctl/kluctl/v2/pkg/utils"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
 	cp "github.com/otiai10/copy"
@@ -18,38 +29,37 @@ import (
 	"helm.sh/helm/v3/pkg/getter"
 	"helm.sh/helm/v3/pkg/registry"
 	"helm.sh/helm/v3/pkg/repo"
-	"net/url"
-	"os"
-	"path/filepath"
-	"regexp"
-	"sort"
-	"strings"
 )
 
 type Chart struct {
-	repo      string
-	localPath string
-	chartName string
-
-	helmAuthProvider auth.HelmAuthProvider
-	ociAuthProvider  auth_provider.OciAuthProvider
+	repo             string
+	localPath        string
+	chartName        string
+	gitUrl           *types.GitUrl
+	gitSubDir        string
+	helmAuthProvider helmauth.HelmAuthProvider
+	ociAuthProvider  ociauth.OciAuthProvider
+	gitRp            *repocache.GitRepoCache
+	ociRp            *repocache.OciRepoCache
 
 	credentialsId string
 
-	versions []string
+	versions []ChartVersion
 }
 
-func NewChart(repo string, localPath string, chartName string, helmAuthProvider auth.HelmAuthProvider, credentialsId string, ociAuthProvider auth_provider.OciAuthProvider) (*Chart, error) {
+func NewChart(repo string, localPath string, chartName string, git *types2.GitProject, helmAuthProvider helmauth.HelmAuthProvider, credentialsId string, ociAuthProvider ociauth.OciAuthProvider, gitRp *repocache.GitRepoCache, ociRp *repocache.OciRepoCache) (*Chart, error) {
 	hc := &Chart{
 		repo:             repo,
 		localPath:        localPath,
 		helmAuthProvider: helmAuthProvider,
 		credentialsId:    credentialsId,
 		ociAuthProvider:  ociAuthProvider,
+		gitRp:            gitRp,
+		ociRp:            ociRp,
 	}
 
-	if localPath == "" && repo == "" {
-		return nil, fmt.Errorf("repo and localPath are missing")
+	if localPath == "" && repo == "" && git == nil {
+		return nil, fmt.Errorf("repo, localPath and git are missing")
 	}
 
 	if hc.IsLocalChart() {
@@ -75,6 +85,25 @@ func NewChart(repo string, localPath string, chartName string, helmAuthProvider
 			return nil, fmt.Errorf("invalid oci chart url: %s", repo)
 		}
 		hc.chartName = chartName
+	} else if git != nil {
+		hc.gitUrl = &git.Url
+		hc.gitSubDir = git.SubDir
+
+		if chartName != "" {
+			return nil, fmt.Errorf("chartName can't be specified when using git repos")
+		}
+		// Use the subDir if possible otherwise use the URL
+		if git.SubDir != "" {
+			hc.chartName = path.Base(git.SubDir)
+			if m, _ := regexp.MatchString(`[a-zA-Z_-]+`, hc.chartName); !m {
+				return nil, fmt.Errorf("invalid git subDir: %s", git.SubDir)
+			}
+		} else {
+			hc.chartName = path.Base(git.Url.Normalize().Path)
+			if m, _ := regexp.MatchString(`[a-zA-Z_-]+`, hc.chartName); !m {
+				return nil, fmt.Errorf("invalid git url: %s", git.Url.String())
+			}
+		}
 	} else if chartName == "" {
 		return nil, fmt.Errorf("chartName is missing")
 	} else {
@@ -83,6 +112,25 @@ func NewChart(repo string, localPath string, chartName string, helmAuthProvider
 
 	return hc, nil
 }
+func (c *Chart) IsLocalChart() bool {
+	return c.localPath != ""
+}
+
+func (c *Chart) IsRegistryChart() bool {
+	return c.IsOciRegistryChart() || c.IsHelmRegistryChart()
+}
+
+func (c *Chart) IsOciRegistryChart() bool {
+	return c.repo != "" && registry.IsOCI(c.repo)
+}
+
+func (c *Chart) IsHelmRegistryChart() bool {
+	return c.repo != "" && !registry.IsOCI(c.repo)
+}
+
+func (c *Chart) IsGitRepositoryChart() bool {
+	return c.gitUrl != nil
+}
 
 func (c *Chart) GetRepo() string {
 	return c.repo
@@ -92,10 +140,6 @@ func (c *Chart) GetLocalPath() string {
 	return c.localPath
 }
 
-func (c *Chart) IsLocalChart() bool {
-	return c.localPath != ""
-}
-
 func (c *Chart) GetLocalChartVersion() (string, error) {
 	chartYaml, err := uo.FromFile(yaml.FixPathExt(filepath.Join(c.localPath, "Chart.yaml")))
 	if err != nil {
@@ -111,29 +155,25 @@ func (c *Chart) GetLocalChartVersion() (string, error) {
 	return x, nil
 }
 
-func (c *Chart) BuildPulledChartDir(baseDir string, version string) (string, error) {
-	if baseDir == "" {
-		return "", fmt.Errorf("can't determine pulled chart dir. No base dir for charts found")
-	}
-
+func (c *Chart) BuildRegistryPulledChartDir(baseDir string) (string, error) {
 	u, err := url.Parse(c.repo)
 	if err != nil {
 		return "", err
 	}
 
-	scheme := ""
+	pathPrefix := ""
 	port := ""
 	switch {
 	case u.Scheme == "oci":
-		scheme = "oci"
+		pathPrefix = "oci"
 		port = u.Port()
 	case u.Scheme == "http":
-		scheme = "http"
+		pathPrefix = "http"
 		if u.Port() != "80" {
 			port = u.Port()
 		}
 	case u.Scheme == "https":
-		scheme = "https"
+		pathPrefix = "https"
 		if u.Port() != "443" {
 			port = u.Port()
 		}
@@ -141,25 +181,101 @@ func (c *Chart) BuildPulledChartDir(baseDir string, version string) (string, err
 		return "", fmt.Errorf("unsupported scheme in %s", u.String())
 	}
 	if port != "" {
-		scheme += "_" + port
+		pathPrefix += "_" + port
 	}
-
 	dir := filepath.Join(
 		baseDir,
-		fmt.Sprintf("%s_%s", scheme, strings.ToLower(u.Hostname())),
+		fmt.Sprintf("%s_%s", pathPrefix, strings.ToLower(u.Hostname())),
 		filepath.FromSlash(strings.ToLower(u.Path)),
 	)
 	if u.Scheme != "oci" {
 		dir = filepath.Join(dir, c.chartName)
 	}
-	if version != "" {
-		dir = filepath.Join(dir, version)
+	return dir, nil
+}
+
+func (c *Chart) BuildVersionedRegistryPulledChartDir(baseDir string, version ChartVersion) (string, error) {
+	dir, err := c.BuildRegistryPulledChartDir(baseDir)
+	if err != nil {
+		return "", err
+	}
+	if version.Version != nil {
+		dir = filepath.Join(dir, *version.Version)
+	}
+	return dir, nil
+}
+
+func (c *Chart) BuildGitRepositoryPulledChartDir(baseDir string) (string, error) {
+	u := c.gitUrl.Normalize()
+	pathPrefix := "git_" + u.Scheme
+	hostname := u.Hostname()
+	if u.Port() != "" {
+		pathPrefix += "_" + u.Port()
+	}
+	dir := filepath.Join(
+		baseDir,
+		fmt.Sprintf("%s_%s", pathPrefix, strings.ToLower(hostname)),
+		filepath.FromSlash(strings.ToLower(u.Path)),
+		filepath.FromSlash(strings.ToLower(c.gitSubDir)),
+	)
+	return dir, nil
+}
+
+func (c *Chart) BuildVersionedGitRepositoryPulledChartDir(baseDir string, version ChartVersion) (string, error) {
+	dir, err := c.BuildGitRepositoryPulledChartDir(baseDir)
+	if err != nil {
+		return "", err
+	}
+	gitVersion := version.String()
+	dir = filepath.Join(dir, filepath.FromSlash(gitVersion))
+	return dir, nil
+}
+
+func (c *Chart) BuildPulledChartDir(baseDir string) (string, error) {
+	var dir string
+	var err error
+	if baseDir == "" {
+		return "", fmt.Errorf("can't determine pulled chart dir. No base dir for charts found")
+	}
+	if c.IsRegistryChart() {
+		dir, err = c.BuildRegistryPulledChartDir(baseDir)
+		if err != nil {
+			return "", err
+		}
+	} else if c.IsGitRepositoryChart() {
+		dir, err = c.BuildGitRepositoryPulledChartDir(baseDir)
+		if err != nil {
+			return "", err
+		}
 	}
 	err = utils.CheckInDir(baseDir, dir)
 	if err != nil {
 		return "", err
 	}
+	return dir, nil
+}
 
+func (c *Chart) BuildVersionedPulledChartDir(baseDir string, version ChartVersion) (string, error) {
+	var dir string
+	var err error
+	if baseDir == "" {
+		return "", fmt.Errorf("can't determine pulled chart dir. No base dir for charts found")
+	}
+	if c.IsRegistryChart() {
+		dir, err = c.BuildVersionedRegistryPulledChartDir(baseDir, version)
+		if err != nil {
+			return "", err
+		}
+	} else if c.IsGitRepositoryChart() {
+		dir, err = c.BuildVersionedGitRepositoryPulledChartDir(baseDir, version)
+		if err != nil {
+			return "", err
+		}
+	}
+	err = utils.CheckInDir(baseDir, dir)
+	if err != nil {
+		return "", err
+	}
 	return dir, nil
 }
 
@@ -206,50 +322,41 @@ func (c *Chart) newRegistryClient(ctx context.Context, settings *cli.EnvSettings
 	return registryClient, cleanup, nil
 }
 
-func (c *Chart) PullToTmp(ctx context.Context, version string) (*PulledChart, error) {
-	if c.IsLocalChart() {
-		return nil, fmt.Errorf("can not pull local charts")
-	}
-
+func (c *Chart) pullFromRegistry(ctx context.Context, version ChartVersion, tmpPullDir string, chartDir string) error {
 	u, err := url.Parse(c.repo)
 	if err != nil {
-		return nil, err
+		return err
 	}
-
-	tmpPullDir, err := os.MkdirTemp(utils.GetTmpBaseDir(ctx), c.chartName+"-pull-")
-	if err != nil {
-		return nil, err
-	}
-	defer os.RemoveAll(tmpPullDir)
-
 	settings := cli.New()
 	registryClient, cleanup, err := c.newRegistryClient(ctx, settings)
 	if err != nil {
-		return nil, err
+		return err
 	}
 	defer cleanup()
 
 	cfg, err := buildHelmConfig(nil, registryClient)
 	if err != nil {
-		return nil, err
+		return err
 	}
 
 	a := action.NewPullWithOpts(action.WithConfig(cfg))
 	a.Settings = settings
 	a.Untar = true
 	a.DestDir = tmpPullDir
-	a.Version = version
+	if version.Version != nil {
+		a.Version = *version.Version
+	}
 
 	if c.credentialsId != "" {
 		if registry.IsOCI(c.repo) {
-			return nil, fmt.Errorf("OCI charts can currently only be authenticated via registry login and environment variables but not via cli arguments")
+			return fmt.Errorf("OCI charts can currently only be authenticated via registry login and environment variables but not via cli arguments")
 		}
 	}
 
 	if !registry.IsOCI(c.repo) {
 		helmCreds, cf, err := c.helmAuthProvider.FindAuthEntry(ctx, *u, c.credentialsId)
 		if err != nil {
-			return nil, err
+			return err
 		}
 		defer cf()
 
@@ -274,26 +381,69 @@ func (c *Chart) PullToTmp(ctx context.Context, version string) (*PulledChart, er
 	if out != "" {
 		status.Infof(ctx, "Message from Helm:\n%s", out)
 	}
+	if err != nil {
+		return err
+	}
+	// move chart
+	des, err := os.ReadDir(filepath.Join(tmpPullDir, c.chartName))
+	if err != nil {
+		return err
+	}
+	for _, de := range des {
+		err = os.Rename(filepath.Join(tmpPullDir, c.chartName, de.Name()), filepath.Join(chartDir, de.Name()))
+		if err != nil {
+			return err
+		}
+	}
+	return nil
+}
+
+func (c *Chart) pullFromGitRepository(ctx context.Context, chartDir string, version ChartVersion) error {
+	m, err := c.gitRp.GetEntry(c.gitUrl.String())
+	if err != nil {
+		return err
+	}
+	cd, gitInfo, err := m.GetClonedDir(version.GitRef)
+	if err != nil {
+		return err
+	}
+	err = cp.Copy(filepath.Join(cd, c.gitSubDir), chartDir)
+	if err != nil {
+		return err
+	}
+
+	err = yaml.WriteYamlFile(filepath.Join(chartDir, ".git-info.yaml"), gitInfo)
+	if err != nil {
+		return err
+	}
+	return nil
+}
+
+func (c *Chart) PullToTmp(ctx context.Context, version ChartVersion) (*PulledChart, error) {
+	if c.IsLocalChart() {
+		return nil, fmt.Errorf("can not pull local charts")
+	}
+
+	tmpPullDir, err := os.MkdirTemp(utils.GetTmpBaseDir(ctx), c.chartName+"-pull-")
 	if err != nil {
 		return nil, err
 	}
+	defer os.RemoveAll(tmpPullDir)
 
 	chartDir, err := os.MkdirTemp(utils.GetTmpBaseDir(ctx), c.chartName+"-pulled-")
 	if err != nil {
 		return nil, err
 	}
-
-	// move chart
-	des, err := os.ReadDir(filepath.Join(tmpPullDir, c.chartName))
+	if c.IsRegistryChart() {
+		err = c.pullFromRegistry(ctx, version, tmpPullDir, chartDir)
+	} else if c.IsGitRepositoryChart() {
+		err = c.pullFromGitRepository(ctx, chartDir, version)
+	} else {
+		return nil, fmt.Errorf("unknown type of helm chart source")
+	}
 	if err != nil {
 		return nil, err
 	}
-	for _, de := range des {
-		err = os.Rename(filepath.Join(tmpPullDir, c.chartName, de.Name()), filepath.Join(chartDir, de.Name()))
-		if err != nil {
-			return nil, err
-		}
-	}
 
 	return NewPulledChart(c, version, chartDir, true), nil
 }
@@ -324,9 +474,9 @@ func (c *Chart) Pull(ctx context.Context, pc *PulledChart) error {
 	return nil
 }
 
-func (c *Chart) doPullCached(ctx context.Context, version string) (*PulledChart, *lockedfile.File, error) {
+func (c *Chart) doPullCached(ctx context.Context, version ChartVersion) (*PulledChart, *lockedfile.File, error) {
 	baseDir := filepath.Join(utils.GetCacheDir(ctx), "helm-charts")
-	cacheDir, err := c.BuildPulledChartDir(baseDir, version)
+	cacheDir, err := c.BuildVersionedPulledChartDir(baseDir, version)
 	_ = os.MkdirAll(cacheDir, 0o755)
 
 	lock, err := lockedfile.Create(cacheDir + ".lock")
@@ -353,7 +503,7 @@ func (c *Chart) doPullCached(ctx context.Context, version string) (*PulledChart,
 	return cached, lock, nil
 }
 
-func (c *Chart) PullCached(ctx context.Context, version string) (*PulledChart, error) {
+func (c *Chart) PullCached(ctx context.Context, version ChartVersion) (*PulledChart, error) {
 	if c.IsLocalChart() {
 		return nil, fmt.Errorf("can not pull local charts")
 	}
@@ -366,7 +516,7 @@ func (c *Chart) PullCached(ctx context.Context, version string) (*PulledChart, e
 	return pc, nil
 }
 
-func (c *Chart) PullInProject(ctx context.Context, baseDir string, version string) (*PulledChart, error) {
+func (c *Chart) PullInProject(ctx context.Context, baseDir string, version ChartVersion) (*PulledChart, error) {
 	if c.IsLocalChart() {
 		return nil, fmt.Errorf("can not pull local charts")
 	}
@@ -395,12 +545,11 @@ func (c *Chart) PullInProject(ctx context.Context, baseDir string, version strin
 	return pc, nil
 }
 
-func (c *Chart) GetPrePulledChart(baseDir string, version string) (*PulledChart, error) {
+func (c *Chart) GetPrePulledChart(baseDir string, version ChartVersion) (*PulledChart, error) {
 	if c.IsLocalChart() {
 		return nil, fmt.Errorf("can not pull local charts")
 	}
-
-	chartDir, err := c.BuildPulledChartDir(baseDir, version)
+	chartDir, err := c.BuildVersionedPulledChartDir(baseDir, version)
 	if err != nil {
 		return nil, err
 	}
@@ -411,11 +560,17 @@ func (c *Chart) QueryVersions(ctx context.Context) error {
 	if c.IsLocalChart() {
 		return fmt.Errorf("can not query versions for local charts")
 	}
-
-	if registry.IsOCI(c.repo) {
-		return c.queryVersionsOci(ctx)
+	if c.IsRegistryChart() {
+		if registry.IsOCI(c.repo) {
+			return c.queryVersionsOci(ctx)
+		} else {
+			return c.queryVersionsHelmRepo(ctx)
+		}
 	}
-	return c.queryVersionsHelmRepo(ctx)
+	if c.IsGitRepositoryChart() {
+		return c.queryVersionsGitRepo(ctx)
+	}
+	return fmt.Errorf("chart type is not supported! Please use a local, registry or repository chart.")
 }
 
 func (c *Chart) queryVersionsOci(ctx context.Context) error {
@@ -439,7 +594,33 @@ func (c *Chart) queryVersionsOci(ctx context.Context) error {
 		return err
 	}
 
-	c.versions = tags
+	c.versions = make([]ChartVersion, 0, len(tags))
+	for _, tag := range tags {
+		c.versions = append(c.versions, ChartVersion{
+			Version: &tag,
+		})
+	}
+
+	return nil
+}
+
+func (c *Chart) queryVersionsGitRepo(ctx context.Context) error {
+	m, err := c.gitRp.GetEntry(c.gitUrl.String())
+	if err != nil {
+		return err
+	}
+	refs := m.GetRepoInfo().RemoteRefs
+
+	c.versions = make([]ChartVersion, 0, len(refs))
+	for ref, _ := range refs {
+		pref, err := types.ParseGitRef(ref)
+		if err != nil {
+			continue
+		}
+		if pref.Tag != "" {
+			c.versions = append(c.versions, ChartVersion{GitRef: &pref})
+		}
+	}
 
 	return nil
 }
@@ -492,32 +673,35 @@ func (c *Chart) queryVersionsHelmRepo(ctx context.Context) error {
 		return fmt.Errorf("helm chart %s not found in Repo index", c.chartName)
 	}
 
-	c.versions = make([]string, 0, indexEntry.Len())
+	c.versions = make([]ChartVersion, 0, indexEntry.Len())
 	for _, x := range indexEntry {
-		c.versions = append(c.versions, x.Version)
+		c.versions = append(c.versions, ChartVersion{
+			Version: &x.Version,
+		})
 	}
 
 	return nil
 }
 
-func (c *Chart) GetLatestVersion(constraints *string) (string, error) {
-	if len(c.versions) == 0 {
-		return "", fmt.Errorf("no versions found or queried")
-	}
+func (c *Chart) GetLatestVersion(constraints *string) (ChartVersion, error) {
+	var nullVersion ChartVersion
 
+	if len(c.versions) == 0 {
+		return nullVersion, fmt.Errorf("no versions found or queried: %s", c.GetChartName())
+	}
 	var err error
 	var updateConstraints *semver.Constraints
 	if constraints != nil {
 		updateConstraints, err = semver.NewConstraint(*constraints)
 		if err != nil {
-			return "", fmt.Errorf("invalid constraints '%s': %w", *constraints, err)
+			return nullVersion, fmt.Errorf("invalid constraints '%s': %w", *constraints, err)
 		}
 	}
 
-	var versions semver.Collection
+	var versions []ChartVersion
 	for _, x := range c.versions {
-		v, err := semver.NewVersion(x)
-		if err != nil {
+		v := x.Semver()
+		if v == nil {
 			continue
 		}
 
@@ -529,17 +713,21 @@ func (c *Chart) GetLatestVersion(constraints *string) (string, error) {
 		} else if !updateConstraints.Check(v) {
 			continue
 		}
-		versions = append(versions, v)
+		versions = append(versions, x)
 	}
 	if len(versions) == 0 {
 		if constraints == nil {
-			return "", fmt.Errorf("no version found")
+			return nullVersion, fmt.Errorf("no version found")
 		} else {
-			return "", fmt.Errorf("no version found that satisfies constraints '%s'", *constraints)
+			return nullVersion, fmt.Errorf("no version found that satisfies constraints '%s'", *constraints)
 		}
 	}
 
-	sort.Stable(versions)
-	latestVersion := versions[len(versions)-1].Original()
+	sort.SliceStable(versions, func(i, j int) bool {
+		a := versions[i].Semver()
+		b := versions[j].Semver()
+		return a.LessThan(b)
+	})
+	latestVersion := versions[len(versions)-1]
 	return latestVersion, nil
 }
