@@ -1,6 +1,7 @@
 package helm
 
 import (
+	"github.com/Masterminds/semver/v3"
 	"github.com/kluctl/kluctl/v2/pkg/k8s"
 	"helm.sh/helm/v3/pkg/action"
 	"helm.sh/helm/v3/pkg/registry"
@@ -12,3 +13,11 @@ func buildHelmConfig(k *k8s.K8sCluster, registryClient *registry.Client) (*actio
 		RegistryClient:   registryClient,
 	}, nil
 }
+
+func IsSemantic(version string) bool {
+	_, err := semver.NewVersion(version)
+	if err != nil {
+		return false
+	}
+	return true
+}
