@@ -1,6 +1,7 @@
 package result
 
 import (
+	gittypes "github.com/kluctl/kluctl/lib/git/types"
 	"github.com/kluctl/kluctl/v2/pkg/types"
 	"github.com/kluctl/kluctl/v2/pkg/types/k8s"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
@@ -39,21 +40,6 @@ const (
 	CommandInititiator_KluctlDeployment                  = "KluctlDeployment"
 )
 
-type ProjectKey struct {
-	RepoKey types.RepoKey `json:"repoKey,omitempty"`
-	SubDir  string        `json:"subDir,omitempty"`
-}
-
-func (k ProjectKey) Less(o ProjectKey) bool {
-	if k.RepoKey != o.RepoKey {
-		return k.RepoKey.String() < o.RepoKey.String()
-	}
-	if k.SubDir != o.SubDir {
-		return k.SubDir < o.SubDir
-	}
-	return false
-}
-
 type TargetKey struct {
 	TargetName    string `json:"targetName,omitempty"`
 	ClusterId     string `json:"clusterId"`
@@ -95,14 +81,6 @@ type CommandInfo struct {
 	ExcludeDeploymentDirs []string               `json:"excludeDeploymentDirs,omitempty"`
 }
 
-type GitInfo struct {
-	Url    *types.GitUrl `json:"url"`
-	Ref    *types.GitRef `json:"ref"`
-	SubDir string        `json:"subDir"`
-	Commit string        `json:"commit"`
-	Dirty  bool          `json:"dirty"`
-}
-
 type ClusterInfo struct {
 	ClusterId string `json:"clusterId"`
 }
@@ -128,13 +106,13 @@ type ResultObject struct {
 type CommandResult struct {
 	Id               string                         `json:"id"`
 	ReconcileId      string                         `json:"reconcileId"`
-	ProjectKey       ProjectKey                     `json:"projectKey"`
+	ProjectKey       gittypes.ProjectKey            `json:"projectKey"`
 	TargetKey        TargetKey                      `json:"targetKey"`
 	Target           types.Target                   `json:"target"`
 	Command          CommandInfo                    `json:"command,omitempty"`
 	KluctlDeployment *KluctlDeploymentInfo          `json:"kluctlDeployment,omitempty"`
 	OverridesPatch   *uo.UnstructuredObject         `json:"overridesPatch,omitempty"`
-	GitInfo          GitInfo                        `json:"gitInfo,omitempty"`
+	GitInfo          gittypes.GitInfo               `json:"gitInfo,omitempty"`
 	ClusterInfo      ClusterInfo                    `json:"clusterInfo"`
 	Deployment       *types.DeploymentProjectConfig `json:"deployment,omitempty"`
 
