@@ -2,15 +2,48 @@ package types
 
 import (
 	"github.com/go-playground/validator/v10"
+	"github.com/kluctl/kluctl/lib/git/types"
+	"github.com/kluctl/kluctl/lib/yaml"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
-	"github.com/kluctl/kluctl/v2/pkg/yaml"
+	"k8s.io/apimachinery/pkg/runtime"
 	"reflect"
 )
 
 type VarsSourceGit struct {
-	Url  GitUrl  `json:"url" validate:"required"`
-	Ref  *GitRef `json:"ref,omitempty"`
-	Path string  `json:"path" validate:"required"`
+	Url  types.GitUrl  `json:"url" validate:"required"`
+	Ref  *types.GitRef `json:"ref,omitempty"`
+	Path string        `json:"path" validate:"required"`
+}
+
+type VarsSourceGitFiles struct {
+	Url types.GitUrl  `json:"url" validate:"required"`
+	Ref *types.GitRef `json:"ref,omitempty"`
+
+	Files []GitFile `json:"files,omitempty"`
+}
+
+type GitFile struct {
+	Glob         string `json:"glob" validate:"required"`
+	Render       bool   `json:"render,omitempty"`
+	ParseYaml    bool   `json:"parseYaml,omitempty"`
+	YamlMultiDoc bool   `json:"yamlMultiDoc,omitempty"`
+}
+
+type GitFileMatch struct {
+	File    GitFile               `json:"file"`
+	Path    string                `json:"path"`
+	Size    int32                 `json:"size"`
+	Content string                `json:"content"`
+	Parsed  *runtime.RawExtension `json:"parsed,omitempty"`
+}
+
+type GitFilesRefMatch struct {
+	Ref    types.GitRef `json:"ref"`
+	RefStr string       `json:"refStr"`
+
+	Files       []GitFileMatch          `json:"files"`
+	FilesByPath map[string]GitFileMatch `json:"filesByPath"`
+	FilesTree   *uo.UnstructuredObject  `json:"filesTree"`
 }
 
 type VarsSourceClusterConfigMapOrSecret struct {
@@ -31,6 +64,31 @@ func ValidateVarsSourceClusterConfigMapOrSecret(sl validator.StructLevel) {
 	}
 }
 
+type VarsSourceClusterObject struct {
+	Kind       string `json:"kind" validate:"required"`
+	ApiVersion string `json:"apiVersion,omitempty"`
+
+	Namespace string `json:"namespace"`
+
+	Name   string            `json:"name,omitempty"`
+	Labels map[string]string `json:"labels,omitempty"`
+	List   bool              `json:"list,omitempty"`
+
+	Path      string `json:"path" validate:"required"`
+	Render    bool   `json:"render,omitempty"`
+	ParseYaml bool   `json:"parseYaml,omitempty"`
+}
+
+func ValidateVarsSourceClusterObject(sl validator.StructLevel) {
+	s := sl.Current().Interface().(VarsSourceClusterObject)
+
+	if s.Name == "" && len(s.Labels) == 0 {
+		sl.ReportError(s, "self", "self", "either name or labels must be set", "")
+	} else if s.Name != "" && len(s.Labels) != 0 {
+		sl.ReportError(s, "self", "self", "only one of name or labels can be set", "")
+	}
+}
+
 type VarsSourceHttp struct {
 	Url      YamlUrl           `json:"url,omitempty" validate:"required"`
 	Method   *string           `json:"method,omitempty"`
@@ -70,17 +128,21 @@ type VarsSource struct {
 	NoOverride    *bool `json:"noOverride,omitempty"`
 	Sensitive     *bool `json:"sensitive,omitempty"`
 
-	Values            *uo.UnstructuredObject              `json:"values,omitempty"`
-	File              *string                             `json:"file,omitempty"`
-	Git               *VarsSourceGit                      `json:"git,omitempty"`
-	ClusterConfigMap  *VarsSourceClusterConfigMapOrSecret `json:"clusterConfigMap,omitempty"`
-	ClusterSecret     *VarsSourceClusterConfigMapOrSecret `json:"clusterSecret,omitempty"`
-	SystemEnvVars     *uo.UnstructuredObject              `json:"systemEnvVars,omitempty"`
-	Http              *VarsSourceHttp                     `json:"http,omitempty"`
-	AwsSecretsManager *VarsSourceAwsSecretsManager        `json:"awsSecretsManager,omitempty"`
-	GcpSecretManager  *VarsSourceGcpSecretManager         `json:"gcpSecretManager,omitempty"`
-	Vault             *VarsSourceVault                    `json:"vault,omitempty"`
-	AzureKeyVault     *VarSourceAzureKeyVault             `json:"azureKeyVault,omitempty"`
+	Values            *uo.UnstructuredObject              `json:"values,omitempty" isVarsSource:"true"`
+	File              *string                             `json:"file,omitempty" isVarsSource:"true"`
+	Git               *VarsSourceGit                      `json:"git,omitempty" isVarsSource:"true"`
+	GitFiles          *VarsSourceGitFiles                 `json:"gitFiles,omitempty" isVarsSource:"true"`
+	ClusterConfigMap  *VarsSourceClusterConfigMapOrSecret `json:"clusterConfigMap,omitempty" isVarsSource:"true"`
+	ClusterSecret     *VarsSourceClusterConfigMapOrSecret `json:"clusterSecret,omitempty" isVarsSource:"true"`
+	ClusterObject     *VarsSourceClusterObject            `json:"clusterObject,omitempty" isVarsSource:"true"`
+	SystemEnvVars     *uo.UnstructuredObject              `json:"systemEnvVars,omitempty" isVarsSource:"true"`
+	Http              *VarsSourceHttp                     `json:"http,omitempty" isVarsSource:"true" isVarsSource:"true"`
+	AwsSecretsManager *VarsSourceAwsSecretsManager        `json:"awsSecretsManager,omitempty" isVarsSource:"true"`
+	GcpSecretManager  *VarsSourceGcpSecretManager         `json:"gcpSecretManager,omitempty" isVarsSource:"true"`
+	Vault             *VarsSourceVault                    `json:"vault,omitempty" isVarsSource:"true"`
+	AzureKeyVault     *VarSourceAzureKeyVault             `json:"azureKeyVault,omitempty" isVarsSource:"true"`
+
+	TargetPath string `json:"targetPath,omitempty"`
 
 	When string `json:"when,omitempty"`
 
@@ -95,11 +157,8 @@ func ValidateVarsSource(sl validator.StructLevel) {
 	count := 0
 	v := reflect.ValueOf(s)
 	for i := 0; i < v.NumField(); i++ {
-		switch v.Type().Field(i).Name {
-		case "IgnoreMissing", "NoOverride", "When", "RenderedSensitive", "RenderedVars":
-			continue
-		}
-		if !v.Field(i).IsNil() {
+		f := v.Type().Field(i)
+		if f.Tag.Get("isVarsSource") == "true" && !v.Field(i).IsNil() {
 			count += 1
 		}
 	}
@@ -113,5 +172,6 @@ func ValidateVarsSource(sl validator.StructLevel) {
 
 func init() {
 	yaml.Validator.RegisterStructValidation(ValidateVarsSourceClusterConfigMapOrSecret, VarsSourceClusterConfigMapOrSecret{})
+	yaml.Validator.RegisterStructValidation(ValidateVarsSourceClusterObject, VarsSourceClusterObject{})
 	yaml.Validator.RegisterStructValidation(ValidateVarsSource, VarsSource{})
 }
