@@ -2,6 +2,8 @@ package uo
 
 import (
 	"fmt"
+	"github.com/ohler55/ojg/jp"
+	"reflect"
 )
 
 func MergeStrMap(a map[string]string, b map[string]string) {
@@ -18,41 +20,63 @@ func CopyMergeStrMap(a map[string]string, b map[string]string) map[string]string
 }
 
 func GetChild(parent interface{}, key interface{}) (interface{}, bool, error) {
-	if m, ok := parent.(map[string]interface{}); ok {
+	if m, ok := getDict(parent); ok {
 		keyStr, ok := key.(string)
 		if !ok {
 			return nil, false, fmt.Errorf("key is not a string")
 		}
 		v, found := m[keyStr]
 		return v, found, nil
-	} else if l, ok := parent.([]interface{}); ok {
+	} else if m, ok := parent.(jp.Keyed); ok {
+		keyStr, ok := key.(string)
+		if !ok {
+			return nil, false, fmt.Errorf("key is not a string")
+		}
+		v, found := m.ValueForKey(keyStr)
+		return v, found, nil
+	}
+
+	v := reflect.ValueOf(parent)
+	if v.Type().Kind() == reflect.Slice {
 		keyInt, ok := key.(int)
 		if !ok {
 			return nil, false, fmt.Errorf("key is not an int")
 		}
-		if keyInt < 0 || keyInt >= len(l) {
+		if keyInt < 0 || keyInt >= v.Len() {
 			return nil, false, fmt.Errorf("index out of bounds")
 		}
-		v := l[keyInt]
-		return v, true, nil
+		e := v.Index(keyInt)
+		return e.Interface(), true, nil
 	}
 	return nil, false, fmt.Errorf("unknown parent type")
 }
 
 func SetChild(parent interface{}, key interface{}, value interface{}) error {
-	if m, ok := parent.(map[string]interface{}); ok {
+	if m, ok := getDict(parent); ok {
 		keyStr, ok := key.(string)
 		if !ok {
 			return fmt.Errorf("key is not a string")
 		}
 		m[keyStr] = value
 		return nil
-	} else if l, ok := parent.([]interface{}); ok {
+	} else if m, ok := parent.(jp.Keyed); ok {
+		keyStr, ok := key.(string)
+		if !ok {
+			return fmt.Errorf("key is not a string")
+		}
+		m.SetValueForKey(keyStr, value)
+		return nil
+	}
+
+	v := reflect.ValueOf(parent)
+	if v.Type().Kind() == reflect.Slice {
 		keyInt, ok := key.(int)
 		if !ok {
 			return fmt.Errorf("key is not an int")
 		}
-		l[keyInt] = value
+
+		e := v.Index(keyInt)
+		e.Set(reflect.ValueOf(value))
 		return nil
 	}
 	return fmt.Errorf("unknown parent type")
