@@ -4,15 +4,16 @@ import (
 	"context"
 	"fmt"
 	"github.com/gin-gonic/gin"
+	gittypes "github.com/kluctl/kluctl/lib/git/types"
+	"github.com/kluctl/kluctl/lib/status"
+	"github.com/kluctl/kluctl/lib/yaml"
 	kluctlv1 "github.com/kluctl/kluctl/v2/api/v1beta1"
 	"github.com/kluctl/kluctl/v2/pkg/results"
-	"github.com/kluctl/kluctl/v2/pkg/status"
 	"github.com/kluctl/kluctl/v2/pkg/types"
 	"github.com/kluctl/kluctl/v2/pkg/types/k8s"
 	"github.com/kluctl/kluctl/v2/pkg/types/result"
 	"github.com/kluctl/kluctl/v2/pkg/utils"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
-	"github.com/kluctl/kluctl/v2/pkg/yaml"
 	"io/fs"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -29,8 +30,8 @@ import (
 const webuiManager = "kluctl-webui"
 
 type ProjectTargetKey struct {
-	Project result.ProjectKey `json:"project"`
-	Target  result.TargetKey  `json:"target"`
+	Project gittypes.ProjectKey `json:"project"`
+	Target  result.TargetKey    `json:"target"`
 }
 
 type CommandResultsServer struct {
@@ -47,7 +48,8 @@ type CommandResultsServer struct {
 	auth   *authHandler
 	events *eventsHandler
 
-	onlyApi bool
+	pathPrefix string
+	onlyApi    bool
 }
 
 func NewCommandResultsServer(
@@ -58,6 +60,7 @@ func NewCommandResultsServer(
 	serverConfig *rest.Config,
 	serverClient client.Client,
 	authConfig AuthConfig,
+	pathPrefix string,
 	onlyApi bool) (*CommandResultsServer, error) {
 
 	ret := &CommandResultsServer{
@@ -67,6 +70,7 @@ func NewCommandResultsServer(
 			ctx: ctx,
 		},
 		serverClient: serverClient,
+		pathPrefix:   pathPrefix,
 		onlyApi:      onlyApi,
 	}
 
@@ -104,11 +108,20 @@ func (s *CommandResultsServer) Run(host string, port int, openBrowser bool) erro
 		gin.SetMode(gin.ReleaseMode)
 	}
 
-	router := gin.New()
-	router.Use(gin.LoggerWithConfig(gin.LoggerConfig{
+	engine := gin.New()
+	engine.Use(gin.LoggerWithConfig(gin.LoggerConfig{
 		SkipPaths: []string{"/healthz", "/readyz"},
 	}))
-	router.Use(gin.Recovery())
+	engine.Use(gin.Recovery())
+
+	engine.GET("/healthz", func(c *gin.Context) {
+		c.Status(http.StatusOK)
+	})
+	engine.GET("/readyz", func(c *gin.Context) {
+		c.Status(http.StatusOK)
+	})
+
+	router := engine.Group(s.pathPrefix)
 
 	err = s.auth.setupRoutes(router)
 	if err != nil {
@@ -122,13 +135,6 @@ func (s *CommandResultsServer) Run(host string, port int, openBrowser bool) erro
 		}
 	}
 
-	router.GET("/healthz", func(c *gin.Context) {
-		c.Status(http.StatusOK)
-	})
-	router.GET("/readyz", func(c *gin.Context) {
-		c.Status(http.StatusOK)
-	})
-
 	api := router.Group("/api", s.auth.authHandler)
 	api.GET("/getShortNames", s.getShortNames)
 	api.GET("/getCommandResult", s.getCommandResult)
@@ -160,7 +166,7 @@ func (s *CommandResultsServer) Run(host string, port int, openBrowser bool) erro
 		BaseContext: func(listener net.Listener) context.Context {
 			return s.ctx
 		},
-		Handler: router.Handler(),
+		Handler: engine.Handler(),
 	}
 
 	if host != "" {
@@ -296,13 +302,13 @@ func (s *CommandResultsServer) redactSensitiveVars(user *User, d *types.Deployme
 		}
 	}
 
-	for _, v := range d.Vars {
-		doRedact(v)
+	for i, _ := range d.Vars {
+		doRedact(&d.Vars[i])
 	}
 
 	for _, di := range d.Deployments {
-		for _, v := range di.Vars {
-			doRedact(v)
+		for i, _ := range di.Vars {
+			doRedact(&di.Vars[i])
 		}
 		s.redactSensitiveVars(user, di.RenderedInclude)
 	}
